tietools.TieChain
=================

.. inheritance-diagram:: abjad.tools.tietools.TieChain.TieChain.TieChain
   :private-bases:

.. autoclass:: abjad.tools.tietools.TieChain.TieChain.TieChain

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.all_leaves_are_in_same_parent

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.duration_in_seconds

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.head

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.is_pitched

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.is_trivial

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.leaves

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.leaves_grouped_by_immediate_parents

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.music

    Inherited from :py:class:`abctools.ScoreSelection <abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection>`

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.preprolated_duration

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.prolated_duration

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.written_duration

Special Methods
---------------

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__contains__

    Inherited from :py:class:`abctools.ScoreSelection <abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection>`

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__eq__

    Inherited from :py:class:`abctools.ScoreSelection <abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection>`

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__getitem__

    Inherited from :py:class:`abctools.ScoreSelection <abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection>`

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__len__

    Inherited from :py:class:`abctools.ScoreSelection <abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection>`

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__ne__

    Inherited from :py:class:`abctools.ScoreSelection <abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection>`

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
